==> xoonips-3.40.tar.gz: xoonips-3.40/itemtypes/xnpfiles/language/ja_utf8/main.php <==
<?php
// $Revision: 1.1.2.2 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.2.2 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XNPFILES_EXPERIMENTER_LABEL", "実験者" );
define( "_MD_XNPFILES_DATA_TYPE_LABEL", "データタイプ" );
define( "_MD_XNPFILES_DATE_LABEL", "日付" );
define( "_MD_XNPFILES_YEAR_LABEL", "年" );
define( "_MD_XNPFILES_MONTH_LABEL", "月" );
define( "_MD_XNPFILES_DAY_OF_MONTH_LABEL", "日" );
define( "_MD_XNPFILES_DATA_FILE_LABEL", "ファイル" );
define( "_MD_XNPFILES_DATA_FILE_NAME", "- ファイル名" );
define( "_MD_XNPFILES_DATA_FILE_MIMETYPE", "- MIMEtype" );
define( "_MD_XNPFILES_DATA_FILE_FILETYPE", "- ファイルタイプ" );
define( "_MD_XNPFILES_CAPTION_LABEL", "見出し" );
define( "_MD_XNPFILES_EXPERIMENTER_REQUIRED", "'実験者' を入力して下さい" );
define( "_MD_XNPFILES_DATA_FILE_REQUIRED", "'データファイル' を入力して下さい" );
define( '_MD_XNPFILES_README_REQUIRED' , "'Readme' を入力して下さい" );
define( '_MD_XNPFILES_LICENSE_REQUIRED', "'License' を入力して下さい" );
define( '_MD_XNPFILES_RIGHTS_REQUIRED' , "'Rights' を入力して下さい" );
define( '_MD_XNPFILES_EXPLANATION' , "ファイル" );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_ID'           , 'アイテムID' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_NAME'     , 'ファイル名' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_MIMETYPE' , 'MIMETｙpe' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_FILETYPE' , 'ファイルタイプ' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_FILE'         , 'ファイル' );

?>

==> xoonips-3.48.tar.gz: xoonips-3.48/itemtypes/xnpfiles/language/ja_utf8/main.php <==
<?php
// $Revision: 1.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.2.4 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XNPFILES_DATE_LABEL", "日付" );
define( "_MD_XNPFILES_DATA_FILE_LABEL", "ファイル" );
define( "_MD_XNPFILES_DATA_FILE_NAME", "- ファイル名" );
define( "_MD_XNPFILES_DATA_FILE_MIMETYPE", "- MIMEタイプ" );
define( "_MD_XNPFILES_DATA_FILE_FILETYPE", "- ファイルタイプ" );
define( "_MD_XNPFILES_DATA_FILE_REQUIRED", "'データファイル' を入力して下さい" );
define( '_MD_XNPFILES_EXPLANATION' , "ファイル" );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_ID'           , 'アイテムID' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_NAME'     , 'ファイル名' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_MIMETYPE' , 'MIMEタイプ' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_FILETYPE' , 'ファイルタイプ' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_FILE'         , 'ファイル' );
